@@ -35,7 +35,3 @@
 .onUnload <- function(libpath) {
   library.dynam.unload("igraph", libpath)
 }
-
-.Last.lib <- function(libpath) {
-  igraph::.onUnload(libpath)
-}
